pitchtools.MelodicChromaticIntervalSegment
==========================================

.. autoclass:: abjad.tools.pitchtools.MelodicChromaticIntervalSegment
   :members:
   :undoc-members:
   :show-inheritance:
